@@ -15,6 +15,7 @@
 #
 import os
 import hashlib
+import time
 from ast import literal_eval
 from typing import Dict, Any, Optional, List
 
@@ -43,20 +44,20 @@ def run_pipeline(
         run_id = session.store["session_id"]
         custom_run_id = hashlib.md5(run_id.encode()).hexdigest()
 
-        return custom_run_id
+    # wait for the queues to finish syncing data to server
+    time.sleep(5)
+    return custom_run_id
 
 
 def prepare_testing_job(custom_run_id):
     return neptune.init(
-            project='common/kedro-integration',
-            api_token='ANONYMOUS',
-            custom_run_id=custom_run_id,
-            capture_stderr=False,
-            capture_stdout=False,
-            capture_hardware_metrics=False,
-            capture_traceback=False,
-            source_files=[]
-        )
+        custom_run_id=custom_run_id,
+        capture_stderr=False,
+        capture_stdout=False,
+        capture_hardware_metrics=False,
+        capture_traceback=False,
+        source_files=[]
+    )
 
 
 def check_node_metadata(run: neptune.Run, node_namespace: str, inputs: List, outputs: Optional[List] = None):
